from distutils.core import setup

setup(
    name    =   "pylistnest",
    version =   '1.1.0',
    py_modules = ['pylistnest'],
    author  = 'sohail ansari',
    description ="""A sample printer
    of neste lists. from head 
    first chapter 1""",
    platform = "mac,windows,linux"
    )
